@@ -164,7 +164,7 @@ class ContractRegistry:
         :return: Contract interface
         :rtype: web3.Contract
         """
-        return ContractRegistry.contracts[contract_name].contract
+        return ContractRegistry.contracts[contract_name]
 
 
 
